@@ -1,14 +1,13 @@
-package MBX::Alien::FLTK::Platform::Windows;
+package inc::MBX::Alien::FLTK::Platform::Windows;
 {
     use strict;
     use warnings;
     use Carp qw[];
     use Config qw[%Config];
-    use lib qw[.. ../../../.. inc];
-    use MBX::Alien::FLTK::Utility
-        qw[_o _a _dir _rel _abs find_h find_lib can_run];
-    use MBX::Alien::FLTK;
-    use base 'MBX::Alien::FLTK::Base';
+    use inc::MBX::Alien::FLTK::Utility
+        qw[_o _a _rel _abs find_h find_lib can_run];
+    use inc::MBX::Alien::FLTK;
+    use base 'inc::MBX::Alien::FLTK::Base';
     $|++;
 
     sub configure {
@@ -34,8 +33,8 @@ package MBX::Alien::FLTK::Platform::Windows;
             print 'Checking for OpenGL... ';
             my $GL_LIB = '';
             $self->notes('config')->{'HAVE_GL'} = 0;
-            if (!$self->assert_lib(lib => 'opengl32', header => 'GL/gl.h')) {
-                print "no\n";
+            if (!$self->assert_lib({lib => 'opengl32', header => 'GL/gl.h'}))
+            {   print "no\n";
                 push @{$self->notes('errors')},
                     {stage   => 'configure',
                      fatal   => 0,
@@ -50,7 +49,8 @@ package MBX::Alien::FLTK::Platform::Windows;
                 #
                 print 'Checking for GL/glu.h... ';
                 $self->notes('config')->{'HAVE_GL_GLU_H'} = 0;
-                if (!$self->assert_lib(lib => 'glu32', header => 'GL/glu.h'))
+                if (!$self->assert_lib({lib => 'glu32', header => 'GL/glu.h'})
+                    )
                 {   print "no\n";
                 }
                 else {
@@ -89,6 +89,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Windows.pm 82d9a05 2009-10-08 03:13:05Z sanko@cpan.org $
+=for git $Id: Windows.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
 
 =cut
